@@ -1,7 +1,7 @@
 package Bencher::Backend;
 
-our $DATE = '2016-03-30'; # DATE
-our $VERSION = '0.45'; # VERSION
+our $DATE = '2016-03-31'; # DATE
+our $VERSION = '0.46'; # VERSION
 
 use 5.010001;
 use strict;
@@ -1288,6 +1288,21 @@ sub format_result {
 $SPEC{bencher} = {
     v => 1.1,
     summary => 'A benchmark framework',
+    description => <<'_',
+
+Bencher is a benchmark framework. You specify a *scenario* (either in a
+`Bencher::Scenario::*` Perl module, or a Perl script, or over the command-line)
+containing list of *participants* and *datasets*. Participants are codes or
+commands to run, and datasets are arguments for the codes/commands. Bencher will
+permute the participants and datasets into benchmark items, ready to run.
+
+You can choose to include only some participants, datasets, or items. And there
+are options to view your scenario's participants/datasets/items/mentioned
+modules, run benchmark against multiple perls and module versions, and so on.
+Bencher comes as a CLI script as well as Perl module. See the `Bencher::Backend`
+documentation for more information.
+
+_
     args_rels => {
         # XXX precision & precision_limit is only relevant when action=bench
         # XXX note is only relevant when action=bench
@@ -2447,7 +2462,7 @@ Bencher::Backend - Backend for Bencher
 
 =head1 VERSION
 
-This document describes version 0.45 of Bencher::Backend (from Perl distribution Bencher-Backend), released on 2016-03-30.
+This document describes version 0.46 of Bencher::Backend (from Perl distribution Bencher-Backend), released on 2016-03-31.
 
 =head1 FUNCTIONS
 
@@ -2456,6 +2471,18 @@ This document describes version 0.45 of Bencher::Backend (from Perl distribution
 
 A benchmark framework.
 
+Bencher is a benchmark framework. You specify a I<scenario> (either in a
+C<Bencher::Scenario::*> Perl module, or a Perl script, or over the command-line)
+containing list of I<participants> and I<datasets>. Participants are codes or
+commands to run, and datasets are arguments for the codes/commands. Bencher will
+permute the participants and datasets into benchmark items, ready to run.
+
+You can choose to include only some participants, datasets, or items. And there
+are options to view your scenario's participants/datasets/items/mentioned
+modules, run benchmark against multiple perls and module versions, and so on.
+Bencher comes as a CLI script as well as Perl module. See the C<Bencher::Backend>
+documentation for more information.
+
 This function is not exported.
 
 Arguments ('*' denotes required arguments):
